@@ -20,7 +20,7 @@
 \********************************************************************/
 
 /** @file client.h
-    @brief xfrp client proxy client related
+    @brief xfrpc proxy client related
     @author Copyright (C) 2016 Dengfeng Liu <liu_df@qq.com>
 */
 
@@ -31,6 +31,7 @@
 
 #include "uthash.h"
 #include "common.h"
+#include "tcpmux.h"
 
 struct event_base;
 struct base_conf;
@@ -42,17 +43,19 @@ struct proxy_client {
 	struct event_base 	*base;
 	struct bufferevent	*ctl_bev; // xfrpc proxy <---> frps
 	struct bufferevent 	*local_proxy_bev; // xfrpc proxy <---> local service
-	struct event		*ev_timeout;
-
 	struct base_conf	*bconf;
-	
-	//private arguments
-	UT_hash_handle hh;
+
+	uint32_t				stream_id;
+	uint32_t				send_window;
+	enum tcp_mux_state		stream_state;
 	int						connected;
 	int 					work_started;
 	struct 	proxy_service 	*ps;
 	unsigned char			*data_tail; // storage untreated data
 	size_t					data_tail_size;
+	
+	// private arguments
+	UT_hash_handle hh;
 };
 
 struct proxy_service {
@@ -75,7 +78,7 @@ struct proxy_service {
 	char	*http_user;
 	char	*http_pwd;
 
-	//provate arguments
+	// private arguments
 	UT_hash_handle hh;
 };
 
@@ -88,13 +91,14 @@ void start_xfrp_tunnel(struct proxy_client *client);
 
 void del_proxy_client(struct proxy_client *client);
 
-void free_proxy_client(struct proxy_client *client);
-
-struct proxy_service *get_proxy_service(const char *proxy_name);
+struct proxy_client	*get_proxy_client(uint32_t sid);
 
 int send_client_data_tail(struct proxy_client *client);
 
 int is_ftp_proxy(const struct proxy_service *ps);
+
 struct proxy_client *new_proxy_client();
 
+void clear_all_proxy_client();
+
 #endif //_CLIENT_H_
