@@ -20,7 +20,7 @@
 \********************************************************************/
 
 /** @file xfrpc.c
-    @brief xfrp client
+    @brief xfrpc client
     @author Copyright (C) 2016 Dengfeng Liu <liu_df@qq.com>
 */
 
