@@ -20,7 +20,7 @@
 \********************************************************************/
 
 /** @file xfrpc.h
-    @brief xfrp client header file
+    @brief xfrpc client header file
     @author Copyright (C) 2016 Dengfeng Liu <liu_df@qq.com>
 */
 
@@ -29,4 +29,4 @@
 
 void xfrpc_loop();
 
-#endif //_XFRPC_H_
\ No newline at end of file
+#endif //_XFRPC_H_
